;; Generated package description from vertico-posframe.el  -*- no-byte-compile: t -*-
(define-package "vertico-posframe" "0.5.9.0.20221219.54658" "Using posframe to show Vertico" '((emacs "26.0") (posframe "1.1.4") (vertico "0.13.0")) :commit "33760e6ca54c30d1eb56a84771d4ad9ccb3e2234" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("abbrev" "convenience" "matching" "vertico") :url "https://github.com/tumashu/vertico-posframe")
